class app():
    def __repr__(self):
        self.run()
        return 'efe'
    def run(self):
        ON = True
        while ON:
            ans = input('tell me something, you moron... ')
            if ans == 'you suck':
                ON = False
                print('but you more!')
            elif ans == 'treasure':
                print('A&P<3')

run = app()

#ned
